" Vim syntax file
" Language:Fvwm{1,2} configuration file
" Maintainer:Haakon Riiser <hakonrk@fys.uio.no>
" Last Change:2002 Jun 2
"
" Thanks to David Necas (Yeti) for adding Fvwm 2.4 support.

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
    syn clear
elseif exists("b:current_syntax")
    finish
endif

" Fvwm configuration files are case insensitive
syn case ignore

" Identifiers in Fvwm can contain most characters, so we only
" include the most common ones here.
if version >= 600
    setlocal iskeyword=_,-,+,.,a-z,A-Z,48-57
else
    set iskeyword=_,-,+,.,a-z,A-Z,48-57
endif

" Read system colors from the color database (rgb.txt)
if exists("rgb_file")
    " We don't want any hit-return prompts, so we make sure that
    " &shortmess is set to `O'
    let __fvwm_oldshm = &shortmess
    set shortmess=O

    " And we set &report to a huge number, so that no hit-return prompts
    " will be given
    let __fvwm_oldreport = &report
    set report=10000

    " Append the color database to the fvwm configuration, and read the
    " colors from this buffer
    let __fvwm_i = line("$") + 1
    exe "$r" rgb_file
    let __fvwm_lastline = line("$")
    while __fvwm_i <= __fvwm_lastline
let __fvwm_s = matchstr(getline(__fvwm_i), '^\s*\d\+\s\+\d\+\s\+\d\+\s\+\h.*$')
if __fvwm_s != ""
    exe "syn keyword fvwmColors ".substitute(__fvwm_s, '^\s*\d\+\s\+\d\+\s\+\d\+\s\+\(\h.*\)$', '\1', "")
endif
let __fvwm_i = __fvwm_i + 1
    endwhile

    " Remove the appended data
    undo

    " Goto first line again
    1

    " and restore the old values of the variables
    let &shortmess = __fvwm_oldshm
    let &report = __fvwm_oldreport
    unlet __fvwm_i __fvwm_s __fvwm_lastline __fvwm_oldshm __fvwm_oldreport
endif
" done reading colors

syn match   fvwmWhitespace"\s\+" contained
syn match   fvwmEnvVar"\$\w\+"
syn match   fvwmModConf"^\s*\*\a\+" contains=fvwmWhitespace
syn match   fvwmString'".\{-}"'
syn match   fvwmRGBValue"#\x\{3}"
syn match   fvwmRGBValue"#\x\{6}"
syn match   fvwmRGBValue"#\x\{9}"
syn match   fvwmRGBValue"#\x\{12}"
syn match   fvwmRGBValue"rgb:\x\{1,4}/\x\{1,4}/\x\{1,4}"
syn match   fvwmPath"\<IconPath\s.*$"lc=8 contains=fvwmEnvVar
syn match   fvwmPath"\<ModulePath\s.*$"lc=10 contains=fvwmEnvVar
syn match   fvwmPath"\<PixmapPath\s.*$"lc=10 contains=fvwmEnvVar
syn match   fvwmModule"\<Module\s\+\w\+"he=s+6
syn match   fvwmKey"\<Key\s\+\w\+"he=s+3
syn keyword fvwmExecExec
syn match   fvwmComment"^#.*$"

if (exists("b:fvwm_version") && b:fvwm_version == 1) || (exists("use_fvwm_1") && use_fvwm_1)
    syn match  fvwmEnvVar"\$(\w\+)"
    syn region fvwmStylematchgroup=fvwmFunction start="^\s*Style\>"hs=e-5 end="$" oneline keepend contains=fvwmString,fvwmKeyword,fvwmWhiteSpace

    syn keyword fvwmFunctionAppsBackingStore AutoRaise BackingStore
    syn keyword fvwmFunctionBeep BoundaryWidth ButtonStyle
    syn keyword fvwmFunctionCenterOnCirculate CirculateDown
    syn keyword fvwmFunctionCirculateHit CirculateSkip
    syn keyword fvwmFunctionCirculateSkipIcons CirculateUp
    syn keyword fvwmFunctionClickTime ClickToFocus Close Cursor
    syn keyword fvwmFunctionCursorMove DecorateTransients Delete
    syn keyword fvwmFunctionDesk DeskTopScale DeskTopSize Destroy
    syn keyword fvwmFunctionDontMoveOff EdgeResistance EdgeScroll
    syn keyword fvwmFunctionEndFunction EndMenu EndPopup Focus
    syn keyword fvwmFunctionFont Function GotoPage HiBackColor
    syn keyword fvwmFunctionHiForeColor Icon IconBox IconFont
    syn keyword fvwmFunctionIconify IconPath Key Lenience Lower
    syn keyword fvwmFunctionMaximize MenuBackColor MenuForeColor
    syn keyword fvwmFunctionMenuStippleColor Module ModulePath Mouse
    syn keyword fvwmFunctionMove MWMBorders MWMButtons MWMDecorHints
    syn keyword fvwmFunctionMWMFunctionHints MWMHintOverride MWMMenus
    syn keyword fvwmFunctionNoBorder NoBoundaryWidth Nop NoPPosition
    syn keyword fvwmFunctionNoTitle OpaqueMove OpaqueResize Pager
    syn keyword fvwmFunctionPagerBackColor PagerFont PagerForeColor
    syn keyword fvwmFunctionPagingDefault PixmapPath Popup Quit Raise
    syn keyword fvwmFunctionRaiseLower RandomPlacement Refresh Resize
    syn keyword fvwmFunctionRestart SaveUnders Scroll SloppyFocus
    syn keyword fvwmFunctionSmartPlacement StartsOnDesk StaysOnTop
    syn keyword fvwmFunctionStdBackColor StdForeColor Stick Sticky
    syn keyword fvwmFunctionStickyBackColor StickyForeColor
    syn keyword fvwmFunctionStickyIcons StubbornIconPlacement
    syn keyword fvwmFunctionStubbornIcons StubbornPlacement
    syn keyword fvwmFunctionSuppressIcons Title TogglePage Wait Warp
    syn keyword fvwmFunctionWindowFont WindowList WindowListSkip
    syn keyword fvwmFunctionWindowsDesk WindowShade XORvalue

    " These keywords are only used after the "Style" command.  To avoid
    " name collision with several commands, they are contained.
    syn keyword fvwmKeywordBackColor BorderWidth BoundaryWidth contained
    syn keyword fvwmKeywordButton CirculateHit CirculateSkip Color contained
    syn keyword fvwmKeywordDoubleClick ForeColor Handles HandleWidth contained
    syn keyword fvwmKeywordIcon IconTitle NoBorder NoBoundaryWidth contained
    syn keyword fvwmKeywordNoButton NoHandles NoIcon NoIconTitle contained
    syn keyword fvwmKeywordNoTitle Slippery StartIconic StartNormal contained
    syn keyword fvwmKeywordStartsAnyWhere StartsOnDesk StaysOnTop contained
    syn keyword fvwmKeywordStaysPut Sticky Title WindowListHit contained
    syn keyword fvwmKeywordWindowListSkip contained
elseif (exists("b:fvwm_version") && b:fvwm_version == 2) || (exists("use_fvwm_2") && use_fvwm_2)
    syn match   fvwmEnvVar"\${\w\+}"
    syn match   fvwmEnvVar"\$\[[^]]\+\]"
    syn match   fvwmEnvVar"\$[$0-9*]"
    syn match   fvwmDef'^\s*+\s*".\{-}"' contains=fvwmMenuString,fvwmWhitespace
    syn match   fvwmIcon'%.\{-}%' contained
    syn match   fvwmIcon'\*.\{-}\*' contained
    syn match   fvwmMenuString'".\{-}"' contains=fvwmIcon,fvwmShortcutKey contained
    syn match   fvwmShortcutKey"&." contained
    syn match   fvwmModule"\<KillModule\s\+\w\+"he=s+10 contains=fvwmModuleName
    syn match   fvwmModule"\<SendToModule\s\+\w\+"he=s+12 contains=fvwmModuleName
    syn match   fvwmModule"\<DestroyModuleConfig\s\+\w\+"he=s+19 contains=fvwmModuleName

    syn keyword fvwmFunctionAddButtonStyle AddTitleStyle AddToDecor AddToFunc
    syn keyword fvwmFunctionAddToMenu AnimatedMove Beep BorderStyle BugOpts
    syn keyword fvwmFunctionBusyCursor ButtonState ButtonStyle ChangeDecor
    syn keyword fvwmFunctionChangeMenuStyle ClickTime Close ColorLimit
    syn keyword fvwmFunctionColormapFocus CopyMenuStyle Current CursorMove
    syn keyword fvwmFunctionCursorStyle DefaultColors DefaultColorset
    syn keyword fvwmFunctionDefaultFont DefaultIcon DefaultLayers Delete Desk
    syn keyword fvwmFunctionDeskTopSize Destroy DestroyDecor DestroyFunc
    syn keyword fvwmFunctionDestroyMenu DestroyMenuStyle Direction Echo
    syn keyword fvwmFunctionEdgeResistance EdgeScroll EdgeThickness Emulate
    syn keyword fvwmFunctionEscapeFunc Exec ExecUseShell ExitFunction
    syn keyword fvwmFunctionFakeClick FlipFocus Focus Function GlobalOpts
    syn keyword fvwmFunctionGnomeButton GotoDesk GotoDeskAndPage GotoPage
    syn keyword fvwmFunctionHideGeometryWindow HilightColor HilightColorset
    syn keyword fvwmFunctionIconFont IconPath Iconify IgnoreModifiers
    syn keyword fvwmFunctionImagePath Key Layer Lower Maximize Menu MenuStyle
    syn keyword fvwmFunctionModulePath ModuleSynchronous ModuleTimeout
    syn keyword fvwmFunctionMouse Move MoveThreshold MoveToDesk MoveToPage
    syn keyword fvwmFunctionMoveToScreen Next None Nop OpaqueMoveSize
    syn keyword fvwmFunctionPipeRead PixmapPath PlaceAgain PointerKey
    syn keyword fvwmFunctionPopup Prev Quit QuitScreen QuitSession Raise
    syn keyword fvwmFunctionRaiseLower Read Recapture RecaptureWindow
    syn keyword fvwmFunctionRefresh RefreshWindow Resize ResizeMove
    syn keyword fvwmFunctionRestart SaveQuitSession SaveSession Scroll
    syn keyword fvwmFunctionSetAnimation SetEnv SetMenuDelay SetMenuStyle
    syn keyword fvwmFunctionSilent SnapAttraction SnapGrid Stick Stroke
    syn keyword fvwmFunctionStrokeFunc Style Title TitleStyle UnsetEnv
    syn keyword fvwmFunctionUpdateDecor UpdateStyles Wait WarpToWindow
    syn keyword fvwmFunctionWindowFont WindowId WindowList WindowShade
    syn keyword fvwmFunctionWindowShadeAnimate WindowsDesk Xinerama
    syn keyword fvwmFunctionXineramaPrimaryScreen XineramaSls XineramaSlsSize
    syn keyword fvwmFunctionXorPixmap XorValue

    syn keyword fvwmKeywordActive ActiveColorset ActiveDown
    syn keyword fvwmKeywordActiveFore ActiveForeOff ActivePlacement
    syn keyword fvwmKeywordActivePlacementHonorsStartsOnPage
    syn keyword fvwmKeywordActivePlacementIgnoresStartsOnPage ActiveUp All
    syn keyword fvwmKeywordAllowRestack Alphabetic Anim Animated Animation
    syn keyword fvwmKeywordAnimationOff AutomaticHotkeys AutomaticHotkeysOff
    syn keyword fvwmKeywordBGradient BackColor Background BackingStore
    syn keyword fvwmKeywordBackingStoreOff BorderColorset BorderWidth
    syn keyword fvwmKeywordBottom Button Button0 Button1 Button2 Button3
    syn keyword fvwmKeywordButton4 Button5 Button6 Button7 Button8
    syn keyword fvwmKeywordButton9 CGradient CaptureHonorsStartsOnPage
    syn keyword fvwmKeywordCaptureIgnoresStartsOnPage CascadePlacement
    syn keyword fvwmKeywordCentered CirculateHit CirculateHitIcon
    syn keyword fvwmKeywordCirculateHitShaded CirculateSkip
    syn keyword fvwmKeywordCirculateSkipIcon CirculateSkipShaded Clear
    syn keyword fvwmKeywordClickToFocus ClickToFocusDoesntPassClick
    syn keyword fvwmKeywordClickToFocusDoesntRaise ClickToFocusPassesClick
    syn keyword fvwmKeywordClickToFocusPassesClickOff ClickToFocusRaises
    syn keyword fvwmKeywordClickToFocusRaisesOff Color Colorset Context
    syn keyword fvwmKeywordCurrentDesk CurrentPage CurrentPageAnyDesk
    syn keyword fvwmKeywordDGradient DecorateTransient Default
    syn keyword fvwmKeywordDepressableBorder Desk DontLowerTransient
    syn keyword fvwmKeywordDontRaiseTransient DontStackTransientParent
    syn keyword fvwmKeywordDoubleClickTime Down DumbPlacement DynamicMenu
    syn keyword fvwmKeywordDynamicPopDownAction DynamicPopUpAction
    syn keyword fvwmKeywordEast Expect FVWM FirmBorder Fixed
    syn keyword fvwmKeywordFixedPosition Flat FlickeringMoveWorkaround
    syn keyword fvwmKeywordFlickeringQtDialogsWorkaround FocusFollowsMouse
    syn keyword fvwmKeywordFollowsFocus FollowsMouse Font ForeColor
    syn keyword fvwmKeywordForeground Function Fvwm FvwmBorder
    syn keyword fvwmKeywordFvwmButtons GNOMEIgnoreHints GNOMEUseHints
    syn keyword fvwmKeywordGrabFocus GrabFocusOff GrabFocusTransient
    syn keyword fvwmKeywordGrabFocusTransientOff Greyed GreyedColorset
    syn keyword fvwmKeywordHGradient HandleWidth Handles Height
    syn keyword fvwmKeywordHiddenHandles Hilight3DOff Hilight3DThick
    syn keyword fvwmKeywordHilight3DThickness Hilight3DThin HilightBack
    syn keyword fvwmKeywordHilightBackOff HilightBorderColorset
    syn keyword fvwmKeywordHilightColorset HilightFore HintOverride
    syn keyword fvwmKeywordHoldSubmenus Icon IconBox IconFill IconFont
    syn keyword fvwmKeywordIconGrid IconOverride IconTitle Iconic
    syn keyword fvwmKeywordIconifyWindowGroups IconifyWindowGroupsOff
    syn keyword fvwmKeywordIcons IgnoreRestack Inactive Interior Item
    syn keyword fvwmKeywordItemFormat KeepWindowGroupsOnDesk Layer Left
    syn keyword fvwmKeywordLeftJustified Lenience LowerTransient MWM
    syn keyword fvwmKeywordMWMBorder MWMButtons MWMDecor MWMDecorMax
    syn keyword fvwmKeywordMWMDecorMenu MWMDecorMin MWMFunctions
    syn keyword fvwmKeywordManualPlacement ManualPlacementHonorsStartsOnPage
    syn keyword fvwmKeywordManualPlacementIgnoresStartsOnPage MaxWindowSize
    syn keyword fvwmKeywordMaximized Menu MenuColorset MenuFace
    syn keyword fvwmKeywordMinOverlapPercentPlacement MinOverlapPlacement
    syn keyword fvwmKeywordMiniIcon MixedVisualWorkaround ModalityIsEvil
    syn keyword fvwmKeywordModuleSynchronous Mouse MouseFocus
    syn keyword fvwmKeywordMouseFocusClickDoesntRaise MouseFocusClickRaises
    syn keyword fvwmKeywordMouseFocusClickRaisesOff Move Mwm MwmBorder
    syn keyword fvwmKeywordMwmButtons MwmDecor MwmFunctions NakedTransient
    syn keyword fvwmKeywordNever NeverFocus NoActiveIconOverride NoButton
    syn keyword fvwmKeywordNoDecorHint NoDeskSort NoFuncHint NoGeometry
    syn keyword fvwmKeywordNoGeometryWithInfo NoHandles NoHotkeys NoIcon
    syn keyword fvwmKeywordNoIconOverride NoIconPosition NoIconTitle
    syn keyword fvwmKeywordNoIcons NoInset NoLenience NoNormal
    syn keyword fvwmKeywordNoOLDecor NoOnBottom NoOnTop NoOverride
    syn keyword fvwmKeywordNoPPosition NoResizeOverride NoSticky
    syn keyword fvwmKeywordNoStipledTitles NoTitle NoTransientPPosition
    syn keyword fvwmKeywordNoTransientUSPosition NoUSPosition
    syn keyword fvwmKeywordNoWarp Normal North Northeast Northwest
    syn keyword fvwmKeywordNotAlphabetic OLDecor OnBottom OnTop Once
    syn keyword fvwmKeywordOnlyIcons OnlyListSkip OnlyNormal OnlyOnBottom
    syn keyword fvwmKeywordOnlyOnTop OnlySticky Opacity ParentalRelativity
    syn keyword fvwmKeywordPixmap PopdownDelayed PopdownDelay PopupDelay
    syn keyword fvwmKeywordPopupAsRootMenu PopupAsSubmenu PopdownImmediately
    syn keyword fvwmKeywordPopupDelayed PopupImmediately PopupOffset
    syn keyword fvwmKeywordQuiet RGradient RaiseOverNativeWindows
    syn keyword fvwmKeywordRaiseOverUnmanaged RaiseTransient
    syn keyword fvwmKeywordRaised Read RecaptureHonorsStartsOnPage
    syn keyword fvwmKeywordRecaptureIgnoresStartsOnPage Rectangle
    syn keyword fvwmKeywordRemoveSubmenus Reset Resize ResizeHintOverride
    syn keyword fvwmKeywordResizeOpaque ResizeOutline ReverseOrder
    syn keyword fvwmKeywordRight RightJustified Root SGradient SameType
    syn keyword fvwmKeywordSaveUnder SaveUnderOff ScatterWindowGroups
    syn keyword fvwmKeywordScreen SelectInPlace SelectOnRelease
    syn keyword fvwmKeywordSelectWarp SeparatorsLong SeparatorsShort
    syn keyword fvwmKeywordShowMapping SideColor SidePic Simple
    syn keyword fvwmKeywordSkipMapping Slippery SlipperyIcon SloppyFocus
    syn keyword fvwmKeywordSmartPlacement SmartPlacementIsNormal
    syn keyword fvwmKeywordSmartPlacementIsReallySmart Solid South
    syn keyword fvwmKeywordSoutheast Southwest StackTransientParent
    syn keyword fvwmKeywordStartIconic StartNormal StartsAnyWhere
    syn keyword fvwmKeywordStartsLowered StartsOnDesk StartsOnPage
    syn keyword fvwmKeywordStartsOnPageIgnoresTransients
    syn keyword fvwmKeywordStartsOnPageIncludesTransients StartsOnScreen
    syn keyword fvwmKeywordStartsRaised StaysOnBottom StaysOnTop StaysPut
    syn keyword fvwmKeywordSticky StickyIcon StipledTitles StippledTitle
    syn keyword fvwmKeywordStippledTitleOff SubmenusLeft SubmenusRight Sunk
    syn keyword fvwmKeywordThis TileCascadePlacement TileManualPlacement
    syn keyword fvwmKeywordTiledPixmap Timeout Title TitleAtBottom
    syn keyword fvwmKeywordTitleAtTop TitleUnderlines0 TitleUnderlines1
    syn keyword fvwmKeywordTitleUnderlines2 TitleWarp TitleWarpOff Top
    syn keyword fvwmKeywordTransient TrianglesRelief TrianglesSolid
    syn keyword fvwmKeywordUp UseBorderStyle UseDecor UseIconName
    syn keyword fvwmKeywordUseIconPosition UseListSkip UsePPosition
    syn keyword fvwmKeywordUseStyle UseTitleStyle UseTransientPPosition
    syn keyword fvwmKeywordUseTransientUSPosition UseUSPosition VGradient
    syn keyword fvwmKeywordVariablePosition Vector VerticalItemSpacing
    syn keyword fvwmKeywordVerticalTitleSpacing WIN Wait Warp WarpTitle
    syn keyword fvwmKeywordWest Win Window WindowListHit WindowListSkip
    syn keyword fvwmKeywordWindowShadeScrolls WindowShadeShrinks
    syn keyword fvwmKeywordWindowShadeSteps Windows XineramaRoot YGradient
    syn keyword fvwmKeywordbottomright default pointer prev quiet
    syn keyword fvwmKeywordTrue False Toggle

    syn keyword fvwmConditionNameAcceptsFocus CurrentDesk CurrentGlobalPage
    syn keyword fvwmConditionNameCurrentGlobalPageAnyDesk CurrentPage
    syn keyword fvwmConditionNameCurrentPageAnyDesk CurrentScreen Iconic Layer
    syn keyword fvwmConditionNameMaximized PlacedByButton3 PlacedByFvwm Raised
    syn keyword fvwmConditionNameShaded Sticky Transient Visible

    syn keyword fvwmContextNameBOTTOM BOTTOM_EDGE BOTTOM_LEFT BOTTOM_RIGHT
    syn keyword fvwmContextNameDEFAULT DESTROY LEFT LEFT_EDGE MENU MOVE
    syn keyword fvwmContextNameRESIZE RIGHT RIGHT_EDGE ROOT SELECT STROKE SYS
    syn keyword fvwmContextNameTITLE TOP TOP_EDGE TOP_LEFT TOP_RIGHT WAIT
    syn keyword fvwmContextNamePOSITION

    syn keyword fvwmFunctionNamecontained FvwmAnimate FvwmAudio FvwmAuto
    syn keyword fvwmFunctionNamecontained FvwmBacker FvwmBanner FvwmButtons
    syn keyword fvwmFunctionNamecontained FvwmCascade FvwmCommandS
    syn keyword fvwmFunctionNamecontained FvwmConsole FvwmConsoleC FvwmCpp
    syn keyword fvwmFunctionNamecontained FvwmDebug FvwmDragWell FvwmEvent
    syn keyword fvwmFunctionNamecontained FvwmForm FvwmGtk FvwmIconBox
    syn keyword fvwmFunctionNamecontained FvwmIconMan FvwmIdent FvwmM4
    syn keyword fvwmFunctionNamecontained FvwmPager FvwmRearrange FvwmSave
    syn keyword fvwmFunctionNamecontained FvwmSaveDesk FvwmScript FvwmScroll
    syn keyword fvwmFunctionNamecontained FvwmTalk FvwmTaskBar FvwmTheme
    syn keyword fvwmFunctionNamecontained FvwmTile FvwmWharf FvwmWinList

    syn keyword fvwmFunctionNameStartFunction InitFunction RestartFunction
    syn keyword fvwmFunctionNameExitFunction SessionInitFunction
    syn keyword fvwmFunctionNameSessionRestartFunction SessionExitFunction
    syn keyword fvwmFunctionNameMissingSubmenuFunction
endif

if version >= 508 || !exists("did_fvwm_syntax_inits")
    if version < 508
let did_fvwm_syntax_inits = 1
command -nargs=+ HiLink hi link <args>
    else
command -nargs=+ HiLink hi def link <args>
    endif

    HiLink fvwmCommentComment
    HiLink fvwmEnvVarMacro
    HiLink fvwmExecFunction
    HiLink fvwmFunctionFunction
    HiLink fvwmFunctionNameSpecial
    HiLink fvwmContextNameFunction
    HiLink fvwmConditionNameFunction
    HiLink fvwmIconComment
    HiLink fvwmKeyFunction
    HiLink fvwmKeywordKeyword
    HiLink fvwmMenuStringString
    HiLink fvwmModConfMacro
    HiLink fvwmModuleFunction
    HiLink fvwmModuleNameSpecial
    HiLink fvwmRGBValueType
    HiLink fvwmShortcutKeySpecialChar
    HiLink fvwmStringString

    if exists("rgb_file")
HiLink fvwmColorsType
    endif

    delcommand HiLink
endif

let b:current_syntax = "fvwm"
" vim: sts=4 sw=4 ts=8